diff --git a/field_tools.admin.inc b/field_tools.admin.inc
index 23fd037..3e78bd5 100644
--- a/field_tools.admin.inc
+++ b/field_tools.admin.inc
@@ -337,7 +337,10 @@ function field_tools_field_edit_form($form, &$form_state, $field) {
     )),
     // Ensure field_ui_field_edit_instance_pre_render() gets called in addition
     // to, not instead of, the #pre_render function(s) needed by all fieldsets.
-    '#pre_render' => array_merge(array('field_ui_field_edit_instance_pre_render'), element_info_property('fieldset', '#pre_render', array())),
+    '#pre_render' => array_merge(
+      array('field_ui_field_edit_instance_pre_render'),
+      \Drupal::service('element_info')->getInfoProperty('fieldset', '#pre_render', array())
+    ),
   );
 
   // Build the non-configurable instance values.
diff --git a/field_tools.services.yml b/field_tools.services.yml
index ee2da15..84ab467 100644
--- a/field_tools.services.yml
+++ b/field_tools.services.yml
@@ -7,6 +7,6 @@ services:
     arguments: ['@entity_type.manager', '@entity.query', '@module_handler']
   field_tools.subscriber:
     class: Drupal\field_tools\Routing\RouteSubscriber
-    arguments: ['@entity.manager']
+    arguments: ['@entity_type.manager']
     tags:
      - { name: event_subscriber }
diff --git a/src/Routing/RouteSubscriber.php b/src/Routing/RouteSubscriber.php
index 7df437b..98ac475 100644
--- a/src/Routing/RouteSubscriber.php
+++ b/src/Routing/RouteSubscriber.php
@@ -2,7 +2,7 @@
 
 namespace Drupal\field_tools\Routing;
 
-use Drupal\Core\Entity\EntityManagerInterface;
+use Drupal\Core\Entity\EntityTypeManagerInterface;
 use Drupal\Core\Routing\RouteSubscriberBase;
 use Drupal\Core\Routing\RoutingEvents;
 use Symfony\Component\Routing\Route;
@@ -14,27 +14,27 @@ use Symfony\Component\Routing\RouteCollection;
 class RouteSubscriber extends RouteSubscriberBase {
 
   /**
-   * The entity type manager
+   * The entity type manager.
    *
-   * @var \Drupal\Core\Entity\EntityManagerInterface
+   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
    */
-  protected $manager;
+  protected $entityTypeManager;
 
   /**
    * Constructs a RouteSubscriber object.
    *
-   * @param \Drupal\Core\Entity\EntityManagerInterface $manager
+   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
    *   The entity type manager.
    */
-  public function __construct(EntityManagerInterface $manager) {
-    $this->manager = $manager;
+  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
+    $this->entityTypeManager = $entity_type_manager;
   }
 
   /**
    * {@inheritdoc}
    */
   protected function alterRoutes(RouteCollection $collection) {
-    foreach ($this->manager->getDefinitions() as $entity_type_id => $entity_type) {
+    foreach ($this->entityTypeManager->getDefinitions() as $entity_type_id => $entity_type) {
       if ($route_name = $entity_type->get('field_ui_base_route')) {
         // Try to get the route from the current collection.
         if (!$entity_route = $collection->get($route_name)) {

diff --git a/src/Plugin/Derivative/FieldToolsLocalTask.php b/src/Plugin/Derivative/FieldToolsLocalTask.php
index 285b19b..e4eb0b5 100644
--- a/src/Plugin/Derivative/FieldToolsLocalTask.php
+++ b/src/Plugin/Derivative/FieldToolsLocalTask.php
@@ -2,7 +2,7 @@
 
 namespace Drupal\field_tools\Plugin\Derivative;
 
-use Drupal\Core\Entity\EntityManagerInterface;
+use Drupal\Core\Entity\EntityTypeManagerInterface;
 use Drupal\Component\Plugin\Derivative\DeriverBase;
 use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
 use Drupal\Core\Routing\RouteProviderInterface;
@@ -24,25 +24,25 @@ class FieldToolsLocalTask extends DeriverBase implements ContainerDeriverInterfa
   protected $routeProvider;
 
   /**
-   * The entity manager
+   * The entity type manager.
    *
-   * @var \Drupal\Core\Entity\EntityManagerInterface
+   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
    */
-  protected $entityManager;
+  protected $entityTypeManager;
 
   /**
    * Creates an FieldToolsLocalTask object.
    *
    * @param \Drupal\Core\Routing\RouteProviderInterface $route_provider
    *   The route provider.
    * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
    *   The entity manager.
    * @param \Drupal\Core\StringTranslation\TranslationInterface $string_translation
    *   The translation manager.
    */
-  public function __construct(RouteProviderInterface $route_provider, EntityManagerInterface $entity_manager, TranslationInterface $string_translation) {
+  public function __construct(RouteProviderInterface $route_provider, EntityTypeManagerInterface $entity_type_manager, TranslationInterface $string_translation) {
     $this->routeProvider = $route_provider;
-    $this->entityManager = $entity_manager;
+    $this->entityTypeManager = $entity_type_manager;
     $this->stringTranslation = $string_translation;
   }
 
@@ -52,7 +52,7 @@ class FieldToolsLocalTask extends DeriverBase implements ContainerDeriverInterfa
   public static function create(ContainerInterface $container, $base_plugin_id) {
     return new static(
       $container->get('router.route_provider'),
-      $container->get('entity.manager'),
+      $container->get('entity_type.manager'),
       $container->get('string_translation')
     );
   }
@@ -63,7 +63,7 @@ class FieldToolsLocalTask extends DeriverBase implements ContainerDeriverInterfa
   public function getDerivativeDefinitions($base_plugin_definition) {
     $this->derivatives = array();
 
-    foreach ($this->entityManager->getDefinitions() as $entity_type_id => $entity_type) {
+    foreach ($this->entityTypeManager->getDefinitions() as $entity_type_id => $entity_type) {
       if ($entity_type->get('field_ui_base_route')) {
         // 'Tools' tab.
         $this->derivatives["field_tools_field_ui_tools_$entity_type_id"] = array(
@@ -24,25 +24,25 @@ class FieldToolsLocalTask extends DeriverBase implements ContainerDeriverInterfa
    * @param \Drupal\Core\Routing\RouteProviderInterface $route_provider
    *   The route provider.
-   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
-   *   The entity manager.
+   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
+   *   The entity type manager.
    * @param \Drupal\Core\StringTranslation\TranslationInterface $string_translation
    *   The translation manager.